ERModel
=======

.. currentmodule:: pykeen.models

.. autoclass:: ERModel
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ERModel.append_weight_regularizer
      ~ERModel.forward

   .. rubric:: Methods Documentation

   .. automethod:: append_weight_regularizer
   .. automethod:: forward
